==> truecrypt-6.1a.tar.gz: truecrypt-6.1a-source/Common/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Common.rc
//
#define IDI_TRUECRYPT_ICON              501
#define IDI_TRUECRYPT_VOL_ICON          502
#define IDD_BENCHMARK_DLG               503
#define IDD_MOUNT_OPTIONS               504
#define IDD_KEYFILES                    505
#define IDR_LANGUAGE                    506
#define IDI_TRUECRYPT                   507
#define IDD_ABOUT_DLG                   508
#define IDD_COMMANDHELP_DLG             509
#define IDD_RAWDEVICES_DLG              510
#define IDC_HOMEPAGE                    511
#define IDR_COMMON_RSRC_HEADER          512
#define IDD_LANGUAGE                    513
#define IDD_CIPHER_TEST_DLG             514
#define IDR_LICENSE                     515
#define IDD_AUXILIARY_DLG               516
#define IDB_TEXTUAL_LOGO_BKG            517
#define IDB_TEXTUAL_LOGO_96DPI          518
#define IDB_TEXTUAL_LOGO_288DPI         519
#define IDR_BOOT_SECTOR                 520
#define IDR_BOOT_SECTOR_AES             521
#define IDR_BOOT_SECTOR_SERPENT         522
#define IDR_BOOT_SECTOR_TWOFISH         523
#define IDR_BOOT_LOADER_DECOMPRESSOR    524
#define IDR_BOOT_LOADER                 525
#define IDR_BOOT_LOADER_AES             526
#define IDR_BOOT_LOADER_SERPENT         527
#define IDR_BOOT_LOADER_TWOFISH         528
#define IDR_RESCUE_BOOT_SECTOR          529
#define IDR_RESCUE_BOOT_SECTOR_AES      530
#define IDR_RESCUE_BOOT_SECTOR_SERPENT  531
#define IDR_RESCUE_BOOT_SECTOR_TWOFISH  532
#define IDR_RESCUE_LOADER               533
#define IDR_RESCUE_LOADER_AES           534
#define IDR_RESCUE_LOADER_SERPENT       535
#define IDR_RESCUE_LOADER_TWOFISH       536
#define IDD_TOKEN_PASSWORD              537
#define IDD_TOKEN_KEYFILES              538
#define IDD_NEW_TOKEN_KEYFILE           539
#define IDT_TOKEN_PASSWORD              5000
#define IDC_PRINT                       5001
#define IDC_KEY                         5002
#define IDC_PLAINTEXT                   5003
#define IDC_CIPHERTEXT                  5004
#define IDC_INFO_BOX_TEXT               5005
#define IDC_SECONDARY_KEY               5006
#define IDD_TEXT_INFO_DIALOG_BOX_DLG    5007
#define IDC_TEST_DATA_UNIT_NUMBER       5008
#define IDD_KEYFILE_GENERATOR           5009
#define IDC_CIPHER                      5010
#define IDD_MULTI_CHOICE_DLG            5011
#define IDC_TEST_BLOCK_NUMBER           5012
#define IDC_POOL_CONTENTS               5013
#define IDC_PRF_ID                      5014
#define IDC_KEY_SIZE                    5015
#define IDC_PLAINTEXT_SIZE              5016
#define IDC_REDTICK                     5017
#define IDC_TESTS_MESSAGE               5018
#define IDC_RESET                       5019
#define IDC_AUTO                        5020
#define IDC_DECRYPT                     5021
#define IDT_TEST_KEY                    5022
#define IDT_TEST_PLAINTEXT              5023
#define IDT_PRF                         5024
#define IDT_XTS_MODE                    5025
#define IDT_TEST_CIPHERTEXT             5026
#define IDT_KEY                         5027
#define IDT_PLAINTEXT                   5028
#define IDC_ENCRYPT                     5029
#define IDT_KEY_UNIT                    5030
#define IDT_CIPHER                      5031
#define IDT_PLAINTEXT_SIZE_UNIT         5032
#define IDC_DEVICELIST                  5033
#define IDT_TEST_BLOCK_NUMBER           5034
#define IDT_SECONDARY_KEY               5035
#define IDC_PERFORM_BENCHMARK           5036
#define IDT_TEST_DATA_UNIT_NUMBER       5037
#define IDC_KEYFILES_HIDVOL_PROT        5038
#define IDC_KEYLIST                     5039
#define IDC_ABOUT_BKG                   5040
#define IDT_ABOUT_VERSION               5041
#define IDT_BOX_BENCHMARK_INFO          5042
#define IDC_ABOUT_CREDITS               5043
#define IDT_SORT_METHOD                 5044
#define IDC_MOUNT_READONLY              5045
#define IDC_MOUNT_REMOVABLE             5046
#define IDC_PROTECT_HIDDEN_VOL          5047
#define IDC_COMMANDHELP_TEXT            5048
#define IDC_USE_EMBEDDED_HEADER_BAK     5049
#define IDC_MOUNT_SYSENC_PART_WITHOUT_PBA 5050
#define IDT_HIDDEN_PROT_PASSWD          5051
#define IDC_RESULTS                     5052
#define IDC_KEYADD                      5053
#define IDC_KEYREMOVE                   5054
#define IDC_KEYREMOVEALL                5055
#define IDC_KEYFILES_ENABLE             5056
#define IDT_HIDDEN_VOL_PROTECTION       5057
#define IDC_ADD_KEYFILE_PATH            5058
#define IDC_BENCHMARK_BUFFER_SIZE       5059
#define IDC_SHOW_PASSWORD_MO            5060
#define IDC_GENERATE_KEYFILE            5061
#define IDC_BENCHMARK_SORT_METHOD       5062
#define IDC_PASSWORD_PROT_HIDVOL        5063
#define IDT_BUFFER_SIZE                 5064
#define IDC_LANGLIST                    5065
#define IDC_KEYFILES_ENABLE_HIDVOL_PROT 5066
#define IDT_KEYFILES_NOTE               5067
#define IDT_KEYFILE_WARNING             5068
#define IDT_KEYFILE_GENERATOR_NOTE      5069
#define IDC_GENERATE_AND_SAVE_KEYFILE   5070
#define IDT_POOL_CONTENTS               5071
#define IDC_GET_LANG_PACKS              5072
#define IDT_LANGPACK_AUTHORS            5073
#define IDC_LANGPACK_CREDITS            5074
#define IDC_LANGPACK_VERSION            5075
#define IDT_ACTIVE_LANG_PACK            5076
#define IDC_DISPLAY_POOL_CONTENTS       5077
#define IDC_XTS_MODE_ENABLED            5078
#define IDC_MULTI_CHOICE_MSG            5079
#define IDC_CHOICE1                     5080
#define IDC_CHOICE5                     5081
#define IDC_CHOICE2                     5082
#define IDC_CHOICE3                     5083
#define IDC_CHOICE4                     5084
#define IDC_CHOICE6                     5085
#define IDC_CHOICE7                     5086
#define IDC_CHOICE8                     5087
#define IDC_CHOICE9                     5088
#define IDC_CHOICE10                    5089
#define IDC_MC_DLG_HR1                  5090
#define IDC_MC_DLG_HR2                  5091
#define IDC_DONATIONS                   5092
#define IDC_LINK_HIDVOL_PROTECTION_INFO 5093
#define IDC_LINK_KEYFILES_INFO          5094
#define IDC_TEXTUAL_LOGO_IMG            5095
#define IDC_ASPECT_RATIO_CALIBRATION_BOX 5096
#define IDC_ABOUT_LOGO_AREA             5097
#define IDC_TOKEN_PASSWORD              5098
#define IDC_TOKEN_FILE_LIST             5099
#define IDC_TOKEN_FILES_ADD             5100
#define IDC_EXPORT                      5101
#define IDC_DELETE                      5102
#define IDC_IMPORT_KEYFILE              5103
#define IDC_SELECTED_TOKEN              5104
#define IDT_SECURITY_TOKEN              5105
#define IDT_TOKEN_KEYFILE_NAME          5106
#define IDC_TOKEN_KEYFILE_NAME          5107
#define IDT_TOKEN_PASSWORD_INFO         5108

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        540
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         5109
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> truecrypt-6.2a.tar.gz: truecrypt-6.2a-source/Common/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Common.rc
//
#define IDI_TRUECRYPT_ICON              501
#define IDI_TRUECRYPT_VOL_ICON          502
#define IDD_BENCHMARK_DLG               503
#define IDD_MOUNT_OPTIONS               504
#define IDD_KEYFILES                    505
#define IDR_LANGUAGE                    506
#define IDI_TRUECRYPT                   507
#define IDD_ABOUT_DLG                   508
#define IDD_COMMANDHELP_DLG             509
#define IDD_RAWDEVICES_DLG              510
#define IDC_HOMEPAGE                    511
#define IDR_COMMON_RSRC_HEADER          512
#define IDD_LANGUAGE                    513
#define IDD_CIPHER_TEST_DLG             514
#define IDR_LICENSE                     515
#define IDD_AUXILIARY_DLG               516
#define IDB_TEXTUAL_LOGO_BKG            517
#define IDB_TEXTUAL_LOGO_96DPI          518
#define IDB_TEXTUAL_LOGO_288DPI         519
#define IDR_BOOT_SECTOR                 520
#define IDR_BOOT_SECTOR_AES             521
#define IDR_BOOT_SECTOR_SERPENT         522
#define IDR_BOOT_SECTOR_TWOFISH         523
#define IDR_BOOT_LOADER_DECOMPRESSOR    524
#define IDR_BOOT_LOADER                 525
#define IDR_BOOT_LOADER_AES             526
#define IDR_BOOT_LOADER_SERPENT         527
#define IDR_BOOT_LOADER_TWOFISH         528
#define IDR_RESCUE_BOOT_SECTOR          529
#define IDR_RESCUE_BOOT_SECTOR_AES      530
#define IDR_RESCUE_BOOT_SECTOR_SERPENT  531
#define IDR_RESCUE_BOOT_SECTOR_TWOFISH  532
#define IDR_RESCUE_LOADER               533
#define IDR_RESCUE_LOADER_AES           534
#define IDR_RESCUE_LOADER_SERPENT       535
#define IDR_RESCUE_LOADER_TWOFISH       536
#define IDD_TOKEN_PASSWORD              537
#define IDD_TOKEN_KEYFILES              538
#define IDD_NEW_TOKEN_KEYFILE           539
#define IDD_RANDOM_POOL_ENRICHMENT      540
#define IDT_TOKEN_PASSWORD              5000
#define IDC_PRINT                       5001
#define IDC_KEY                         5002
#define IDC_PLAINTEXT                   5003
#define IDC_CIPHERTEXT                  5004
#define IDC_INFO_BOX_TEXT               5005
#define IDC_SECONDARY_KEY               5006
#define IDD_TEXT_INFO_DIALOG_BOX_DLG    5007
#define IDC_TEST_DATA_UNIT_NUMBER       5008
#define IDD_KEYFILE_GENERATOR           5009
#define IDC_CIPHER                      5010
#define IDD_MULTI_CHOICE_DLG            5011
#define IDC_TEST_BLOCK_NUMBER           5012
#define IDC_POOL_CONTENTS               5013
#define IDC_PRF_ID                      5014
#define IDC_KEY_SIZE                    5015
#define IDC_PLAINTEXT_SIZE              5016
#define IDC_REDTICK                     5017
#define IDC_TESTS_MESSAGE               5018
#define IDC_RESET                       5019
#define IDC_AUTO                        5020
#define IDC_DECRYPT                     5021
#define IDT_TEST_KEY                    5022
#define IDT_TEST_PLAINTEXT              5023
#define IDT_PRF                         5024
#define IDT_XTS_MODE                    5025
#define IDT_TEST_CIPHERTEXT             5026
#define IDT_KEY                         5027
#define IDT_PLAINTEXT                   5028
#define IDC_ENCRYPT                     5029
#define IDT_KEY_UNIT                    5030
#define IDT_CIPHER                      5031
#define IDT_PLAINTEXT_SIZE_UNIT         5032
#define IDC_DEVICELIST                  5033
#define IDT_TEST_BLOCK_NUMBER           5034
#define IDT_SECONDARY_KEY               5035
#define IDC_PERFORM_BENCHMARK           5036
#define IDT_TEST_DATA_UNIT_NUMBER       5037
#define IDC_KEYFILES_HIDVOL_PROT        5038
#define IDC_KEYLIST                     5039
#define IDC_ABOUT_BKG                   5040
#define IDT_ABOUT_VERSION               5041
#define IDT_BOX_BENCHMARK_INFO          5042
#define IDC_ABOUT_CREDITS               5043
#define IDT_SORT_METHOD                 5044
#define IDC_MOUNT_READONLY              5045
#define IDC_MOUNT_REMOVABLE             5046
#define IDC_PROTECT_HIDDEN_VOL          5047
#define IDC_COMMANDHELP_TEXT            5048
#define IDC_USE_EMBEDDED_HEADER_BAK     5049
#define IDC_MOUNT_SYSENC_PART_WITHOUT_PBA 5050
#define IDT_HIDDEN_PROT_PASSWD          5051
#define IDC_RESULTS                     5052
#define IDC_KEYADD                      5053
#define IDC_KEYREMOVE                   5054
#define IDC_KEYREMOVEALL                5055
#define IDC_KEYFILES_ENABLE             5056
#define IDT_HIDDEN_VOL_PROTECTION       5057
#define IDC_ADD_KEYFILE_PATH            5058
#define IDC_BENCHMARK_BUFFER_SIZE       5059
#define IDC_SHOW_PASSWORD_MO            5060
#define IDC_GENERATE_KEYFILE            5061
#define IDC_BENCHMARK_SORT_METHOD       5062
#define IDC_PASSWORD_PROT_HIDVOL        5063
#define IDT_BUFFER_SIZE                 5064
#define IDC_LANGLIST                    5065
#define IDC_KEYFILES_ENABLE_HIDVOL_PROT 5066
#define IDT_KEYFILES_NOTE               5067
#define IDT_KEYFILE_WARNING             5068
#define IDT_KEYFILE_GENERATOR_NOTE      5069
#define IDC_GENERATE_AND_SAVE_KEYFILE   5070
#define IDT_POOL_CONTENTS               5071
#define IDC_GET_LANG_PACKS              5072
#define IDT_LANGPACK_AUTHORS            5073
#define IDC_LANGPACK_CREDITS            5074
#define IDC_LANGPACK_VERSION            5075
#define IDT_ACTIVE_LANG_PACK            5076
#define IDC_DISPLAY_POOL_CONTENTS       5077
#define IDC_XTS_MODE_ENABLED            5078
#define IDC_MULTI_CHOICE_MSG            5079
#define IDC_CHOICE1                     5080
#define IDC_CHOICE5                     5081
#define IDC_CHOICE2                     5082
#define IDC_CHOICE3                     5083
#define IDC_CHOICE4                     5084
#define IDC_CHOICE6                     5085
#define IDC_CHOICE7                     5086
#define IDC_CHOICE8                     5087
#define IDC_CHOICE9                     5088
#define IDC_CHOICE10                    5089
#define IDC_MC_DLG_HR1                  5090
#define IDC_MC_DLG_HR2                  5091
#define IDC_DONATIONS                   5092
#define IDC_LINK_HIDVOL_PROTECTION_INFO 5093
#define IDC_LINK_KEYFILES_INFO          5094
#define IDC_TEXTUAL_LOGO_IMG            5095
#define IDC_ASPECT_RATIO_CALIBRATION_BOX 5096
#define IDC_ABOUT_LOGO_AREA             5097
#define IDC_TOKEN_PASSWORD              5098
#define IDC_TOKEN_FILE_LIST             5099
#define IDC_TOKEN_FILES_ADD             5100
#define IDC_EXPORT                      5101
#define IDC_DELETE                      5102
#define IDC_IMPORT_KEYFILE              5103
#define IDC_SELECTED_TOKEN              5104
#define IDT_SECURITY_TOKEN              5105
#define IDT_TOKEN_KEYFILE_NAME          5106
#define IDC_TOKEN_KEYFILE_NAME          5107
#define IDT_TOKEN_PASSWORD_INFO         5108
#define IDT_RANDOM_POOL_ENRICHMENT_NOTE 5109
#define IDC_CONTINUE                    5110

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        541
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         5111
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
